@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: property.cc 280 2006-05-10 13:12:40Z murrayc $ */
+/* $Id: property.cc,v 1.2 2006/04/12 08:12:11 murrayc Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -19,9 +19,6 @@
  */
 
 #include <glibmm/property.h>
-
-#ifdef GLIBMM_PROPERTIES_ENABLED
-
 #include <glibmm/object.h>
 #include <cstddef>
 
@@ -199,5 +196,3 @@ void PropertyBase::notify()
 
 } // namespace Glib
 
-#endif //GLIBMM_PROPERTIES_ENABLED
-
